==> currency_cloud-0.2.0.tar.gz: test/src/beneficiaries_api_test.dart <==
library currency_cloud.beneficiaries_api_test;

import 'dart:async';

import 'package:currency_cloud/currency_cloud.dart';
import 'package:mockito/mockito.dart';
import 'package:money/money.dart';
import 'package:test/test.dart';

import 'mock_client.dart';

main() {
  group('BeneficiariesApi', () {
    BeneficiariesApi beneficiariesApi;
    MockClient mockClient;

    final bankAccountHolderName = 'John Doe';
    final bankCountry = 'GB';
    final currencyCode = 'GBP';
    final currency = new Currency(currencyCode);
    final name = 'Employee Funds';

    final email = 'john.doe@acme.com';
    final beneficiaryAddress = '23 Acacia Road';
    final beneficiaryCountry = 'GB';
    final accountNumber = '3284734675';
    final routingCodeType1 = 'aba';
    final routingCodeValue1 = '011103093';
    final routingCodeType2 = 'bsb_code';
    final routingCodeValue2 = '088';
    final bicSwift = 'DABADKKK';
    final iban = 'AD1200012030200359100100';
    final defaultBeneficiary = true;
    final bankAddress = '4356 Wisteria Lane';
    final bankName = 'HSBC Bank';
    final bankAccountType = 'checking';
    final beneficiaryEntityType = 'individual';
    final beneficiaryCompanyName = 'Some Company LLC';
    final beneficiaryFirstName = 'John';
    final beneficiaryLastName = 'Doe';
    final beneficiaryCity = 'London';
    final beneficiaryPostcode = 'W11 2BQ';
    final beneficiaryStateOrProvince = 'TX';
    final beneficiaryDateOfBirth = '2010-10-10';
    final beneficiaryIdentificationType = 'drivers_license';
    final beneficiaryIdentificationValue = 'AE02315508BF';
    final paymentTypes = PaymentType.priority.id;
    final onBehalfOf = '6188410c-44bf-41d4-810f-8a766c3035b0';

    setUp(() {
      mockClient = new MockClient();
      beneficiariesApi = new BeneficiariesApi(mockClient);
      beneficiariesApi.client = mockClient;
    });

    test('call with minimum amount of parameters should cause according post call', () async {
      final answer = {'much_answer': 'very_custom'};
      when(mockClient.post(any, body: any)).thenReturn(new Future.value(answer));
      final result = await beneficiariesApi.create(bankAccountHolderName, bankCountry, currency, name);

      final uri = '/beneficiaries/create';
      final body = {
        'bank_account_holder_name': bankAccountHolderName,
        'bank_country': bankCountry,
        'currency': currencyCode,
        'name': name
      };

      verify(mockClient.post(uri, body: body)).called(1);
      expect(result, answer);
    });

    test('call with maximum amount of parameters should cause according post call', () async {
      final answer = {'much_answer': 'very_custom'};
      when(mockClient.post(any, body: any)).thenReturn(new Future.value(answer));
      final result = await beneficiariesApi.create(bankAccountHolderName, bankCountry, currency, name,
          email: email,
          beneficiaryAddress: beneficiaryAddress,
          beneficiaryCountry: beneficiaryCountry,
          accountNumber: accountNumber,
          routingCodeType1: routingCodeType1,
          routingCodeValue1: routingCodeValue1,
          routingCodeType2: routingCodeType2,
          routingCodeValue2: routingCodeValue2,
          bicSwift: bicSwift,
          iban: iban,
          defaultBeneficiary: defaultBeneficiary,
          bankAddress: bankAddress,
          bankName: bankName,
          bankAccountType: bankAccountType,
          beneficiaryEntityType: beneficiaryEntityType,
          beneficiaryCompanyName: beneficiaryCompanyName,
          beneficiaryFirstName: beneficiaryFirstName,
          beneficiaryLastName: beneficiaryLastName,
          beneficiaryCity: beneficiaryCity,
          beneficiaryPostcode: beneficiaryPostcode,
          beneficiaryStateOrProvince: beneficiaryStateOrProvince,
          beneficiaryDateOfBirth: beneficiaryDateOfBirth,
          beneficiaryIdentificationType: beneficiaryIdentificationType,
          beneficiaryIdentificationValue: beneficiaryIdentificationValue,
          paymentTypes: paymentTypes,
          onBehalfOf: onBehalfOf);

      final uri = '/beneficiaries/create';
      final body = {
        'bank_account_holder_name': bankAccountHolderName,
        'bank_country': bankCountry,
        'currency': currencyCode,
        'name': name,
        'email': 'john.doe@acme.com',
        'beneficiary_address': '23 Acacia Road',
        'beneficiary_country': 'GB',
        'account_number': '3284734675',
        'routing_code_type_1': 'aba',
        'routing_code_value_1': '011103093',
        'routing_code_type_2': 'bsb_code',
        'routing_code_value_2': '088',
        'bic_swift': 'DABADKKK',
        'iban': 'AD1200012030200359100100',
        'default_beneficiary': true,
        'bank_address': '4356 Wisteria Lane',
        'bank_name': 'HSBC Bank',
        'bank_account_type': 'checking',
        'beneficiary_entity_type': 'individual',
        'beneficiary_company_name': 'Some Company LLC',
        'beneficiary_first_name': 'John',
        'beneficiary_last_name': 'Doe',
        'beneficiary_city': 'London',
        'beneficiary_postcode': 'W11 2BQ',
        'beneficiary_state_or_province': 'TX',
        'beneficiary_date_of_birth': '2010-10-10',
        'beneficiary_identification_type': 'drivers_license',
        'beneficiary_identification_value': 'AE02315508BF',
        'payment_types': 'priority',
        'on_behalf_of': '6188410c-44bf-41d4-810f-8a766c3035b0',
      };

      verify(mockClient.post(uri, body: body));
      expect(result, answer);
    });
  });
}

==> currency_cloud-0.2.1.tar.gz: test/src/beneficiaries_api_test.dart <==
library currency_cloud.beneficiaries_api_test;

import 'dart:async';

import 'package:currency_cloud/currency_cloud.dart';
import 'package:mockito/mockito.dart';
import 'package:money/money.dart';
import 'package:test/test.dart';

import 'mock_client.dart';

main() {
  group('BeneficiariesApi', () {
    BeneficiariesApi beneficiariesApi;
    MockClient mockClient;

    final bankAccountHolderName = 'John Doe';
    final bankCountry = 'GB';
    final currencyCode = 'GBP';
    final currency = new Currency(currencyCode);
    final name = 'Employee Funds';

    final email = 'john.doe@acme.com';
    final beneficiaryAddress = '23 Acacia Road';
    final beneficiaryCountry = 'GB';
    final accountNumber = '3284734675';
    final routingCodeType1 = 'aba';
    final routingCodeValue1 = '011103093';
    final routingCodeType2 = 'bsb_code';
    final routingCodeValue2 = '088';
    final bicSwift = 'DABADKKK';
    final iban = 'AD1200012030200359100100';
    final defaultBeneficiary = true;
    final bankAddress = '4356 Wisteria Lane';
    final bankName = 'HSBC Bank';
    final bankAccountType = 'checking';
    final beneficiaryEntityType = 'individual';
    final beneficiaryCompanyName = 'Some Company LLC';
    final beneficiaryFirstName = 'John';
    final beneficiaryLastName = 'Doe';
    final beneficiaryCity = 'London';
    final beneficiaryPostcode = 'W11 2BQ';
    final beneficiaryStateOrProvince = 'TX';
    final beneficiaryDateOfBirth = '2010-10-10';
    final beneficiaryIdentificationType = 'drivers_license';
    final beneficiaryIdentificationValue = 'AE02315508BF';
    final paymentTypes = PaymentType.priority.id;
    final onBehalfOf = '6188410c-44bf-41d4-810f-8a766c3035b0';

    setUp(() {
      mockClient = new MockClient();
      beneficiariesApi = new BeneficiariesApi(mockClient);
      beneficiariesApi.client = mockClient;
    });

    test('call with minimum amount of parameters should cause according post call', () async {
      final answer = {'much_answer': 'very_custom'};
      when(mockClient.post(any, body: any)).thenReturn(new Future.value(answer));
      final result = await beneficiariesApi.create(bankAccountHolderName, bankCountry, currency, name);

      final uri = '/beneficiaries/create';
      final body = {
        'bank_account_holder_name': bankAccountHolderName,
        'bank_country': bankCountry,
        'currency': currencyCode,
        'name': name
      };

      verify(mockClient.post(uri, body: body)).called(1);
      expect(result, answer);
    });

    test('call with maximum amount of parameters should cause according post call', () async {
      final answer = {'much_answer': 'very_custom'};
      when(mockClient.post(any, body: any)).thenReturn(new Future.value(answer));
      final result = await beneficiariesApi.create(bankAccountHolderName, bankCountry, currency, name,
          email: email,
          beneficiaryAddress: beneficiaryAddress,
          beneficiaryCountry: beneficiaryCountry,
          accountNumber: accountNumber,
          routingCodeType1: routingCodeType1,
          routingCodeValue1: routingCodeValue1,
          routingCodeType2: routingCodeType2,
          routingCodeValue2: routingCodeValue2,
          bicSwift: bicSwift,
          iban: iban,
          defaultBeneficiary: defaultBeneficiary,
          bankAddress: bankAddress,
          bankName: bankName,
          bankAccountType: bankAccountType,
          beneficiaryEntityType: beneficiaryEntityType,
          beneficiaryCompanyName: beneficiaryCompanyName,
          beneficiaryFirstName: beneficiaryFirstName,
          beneficiaryLastName: beneficiaryLastName,
          beneficiaryCity: beneficiaryCity,
          beneficiaryPostcode: beneficiaryPostcode,
          beneficiaryStateOrProvince: beneficiaryStateOrProvince,
          beneficiaryDateOfBirth: beneficiaryDateOfBirth,
          beneficiaryIdentificationType: beneficiaryIdentificationType,
          beneficiaryIdentificationValue: beneficiaryIdentificationValue,
          paymentTypes: paymentTypes,
          onBehalfOf: onBehalfOf);

      final uri = '/beneficiaries/create';
      final body = {
        'bank_account_holder_name': bankAccountHolderName,
        'bank_country': bankCountry,
        'currency': currencyCode,
        'name': name,
        'email': 'john.doe@acme.com',
        'beneficiary_address': '23 Acacia Road',
        'beneficiary_country': 'GB',
        'account_number': '3284734675',
        'routing_code_type_1': 'aba',
        'routing_code_value_1': '011103093',
        'routing_code_type_2': 'bsb_code',
        'routing_code_value_2': '088',
        'bic_swift': 'DABADKKK',
        'iban': 'AD1200012030200359100100',
        'default_beneficiary': 'true',
        'bank_address': '4356 Wisteria Lane',
        'bank_name': 'HSBC Bank',
        'bank_account_type': 'checking',
        'beneficiary_entity_type': 'individual',
        'beneficiary_company_name': 'Some Company LLC',
        'beneficiary_first_name': 'John',
        'beneficiary_last_name': 'Doe',
        'beneficiary_city': 'London',
        'beneficiary_postcode': 'W11 2BQ',
        'beneficiary_state_or_province': 'TX',
        'beneficiary_date_of_birth': '2010-10-10',
        'beneficiary_identification_type': 'drivers_license',
        'beneficiary_identification_value': 'AE02315508BF',
        'payment_types': 'priority',
        'on_behalf_of': '6188410c-44bf-41d4-810f-8a766c3035b0',
      };

      verify(mockClient.post(uri, body: body));
      expect(result, answer);
    });
  });
}
